@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of plotextractor.
-# Copyright (C) 2015, 2016 CERN.
+# Copyright (C) 2015, 2016, 2020 CERN.
 #
 # plotextractor is free software; you can redistribute it
 # and/or modify it under the terms of the GNU General Public License as
@@ -22,14 +22,12 @@
 # waive the privileges and immunities granted to it by virtue of its status
 # as an Intergovernmental Organization or submit itself to any jurisdiction.
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import tempfile
 
 import pytest
 import plotextractor
-from plotextractor import process_tarball
 
 
 @pytest.fixture
@@ -40,14 +38,6 @@ def tarball_flat():
                         '1508.03176v1.tar.gz')
 
 
-@pytest.fixture
-def tarball_test_for_include():
-    """Return path to testdata with include tags."""
-    return os.path.join(os.path.dirname(__file__),
-                        'data',
-                        '2207.tar.gz')
-
-
 @pytest.fixture
 def tarball_rotation():
     """Return path to testdata with an image file with rotation."""
@@ -81,18 +71,11 @@ def tarball_nested_folder_rotation():
 
 
 @pytest.fixture
-def tarball_utf():
+def tarball_with_wrong_utf():
     """Return path to testdata with images in a nested folder."""
     return os.path.join(os.path.dirname(__file__),
                         'data',
-                        '2003.02673.tar.gz')
-
-@pytest.fixture
-def tarball_subfloat():
-    """Return path to testdata with subfloats."""
-    return os.path.join(os.path.dirname(__file__),
-                        'data',
-                        '2203.14536.tar.gz')
+                        'wrong_unicode_path.tar.gz')
 
 
 def test_process_api(tarball_flat):
@@ -141,6 +124,7 @@ def test_process_api_preserves_ordering_of_figures_with_one_source_file(tarball_
     assert expected == labels
 
 
+
 def test_process_api_with_context(tarball_flat):
     """Test simple API for extracting and linking files to TeX context."""
     plots = plotextractor.process_tarball(tarball_flat, context=True)
@@ -184,16 +168,6 @@ def test_process_api_with_image_rotation(tarball_rotation):
     assert "name" in plots[0]
 
 
-def test_process_api_with_subfloats(tarball_subfloat):
-    """Test simple API for extracting and linking files to TeX context."""
-    plots = plotextractor.process_tarball(tarball_subfloat)
-    assert len(plots) == 24
-    assert "label" in plots[0]
-    assert "original_url" in plots[0]
-    assert "captions" in plots[0]
-    assert "name" in plots[0]
-
-
 def test_process_api_invalid_text():
     """Test simple API for extracting and linking files to TeX."""
     with tempfile.NamedTemporaryFile() as f:
@@ -207,21 +181,10 @@ def test_process_api_no_tex(tarball_no_tex):
         plotextractor.process_tarball(tarball_no_tex)
 
 
-def test_process_tarball_with_utf_folder(tarball_utf):
-    """Tests tarball with utf - Shouldn't break"""
-    temporary_dir = tempfile.mkdtemp()
-    plots = process_tarball(
-        tarball_utf,
-        output_directory=temporary_dir
-    )
-
-
-def test_process_api_with_include(tarball_test_for_include):
-    """Test simple API for including the plots for \include tag."""
-    plots = plotextractor.process_tarball(tarball_test_for_include, context=True)
-    assert len(plots) == 155
-    assert "contexts" in plots[0]
-    assert "label" in plots[0]
-    assert "original_url" in plots[0]
-    assert "captions" in plots[0]
-    assert "name" in plots[0]
+def test_process_tarball_with_wrong_utf_path_inside(tarball_with_wrong_utf):
+    """Test simple API for extracting and linking files to TeX context."""
+    plots = plotextractor.process_tarball(tarball_with_wrong_utf, context=True)
+    assert len(plots) == 1
+    assert "unicode_path.tar.gz_files/cute_cat.png" in plots[0]['url']
+    assert plots[0]['captions'] == ['słodki kociak!']
+    assert plots[0]['name'] == 'cute_cat'
